pub struct CreditNoteDetails {
pub reference_invoice_number: Option<String>,
pub debit_note_number: Option<String>,
pub returns_reference_number: Option<String>,
pub goods_return_date: Option<String>,
pub rma_id: Option<String>,
pub coop_reference_number: Option<String>,
pub consignors_reference_number: Option<String>,
}Expand description
CreditNoteDetails : References required in order to process a credit note. This information is required only if InvoiceType is CreditNote.
Fields
reference_invoice_number: Option<String>Original Invoice Number when sending a credit note relating to an existing invoice. One Invoice only to be processed per Credit Note. This is mandatory for AP Credit Notes.
debit_note_number: Option<String>Debit Note Number as generated by Amazon. Recommended for Returns and COOP Credit Notes.
returns_reference_number: Option<String>Identifies the Returns Notice Number. Mandatory for all Returns Credit Notes.
goods_return_date: Option<String>Defines a date and time according to ISO8601.
rma_id: Option<String>Identifies the Returned Merchandise Authorization ID, if generated.
coop_reference_number: Option<String>Identifies the COOP reference used for COOP agreement. Failure to provide the COOP reference number or the Debit Note number may lead to a rejection of the Credit Note.
consignors_reference_number: Option<String>Identifies the consignor reference number (VRET number), if generated by Amazon.
Implementations
sourceimpl CreditNoteDetails
impl CreditNoteDetails
sourcepub fn new() -> CreditNoteDetails
pub fn new() -> CreditNoteDetails
References required in order to process a credit note. This information is required only if InvoiceType is CreditNote.